Visualisation of the Graph. This module is for visualising a Graph.

THIS IS A WORK IN PROGRESS !

Ideally, I want to be able to visualise the graph by using the dot language. At the moment, I’m simply trying to make a function that outputs dot code for a given graph.

Functions