pub struct Vertex {
pub partials: [f64; 2],
pub parents: [usize; 2],
}Expand description
Struct defining the vertex of the computational graph.
Operations are assumed to be binary (e.g. x + y), thus the arrays have two elements. To deal with unary or nullary operations, we just adjust the weights (partials) and the dependencies (parents).
Fields
partials: [f64; 2]Array that contains the partial derivatives wrt to x and y.
parents: [usize; 2]Array that contains the indices of the parent vertices.
Implementations
sourceimpl Vertex
impl Vertex
sourcepub fn get_partials(&self) -> [f64; 2]
pub fn get_partials(&self) -> [f64; 2]
Get the partials of the vertex.
sourcepub fn get_parents(&self) -> [usize; 2]
pub fn get_parents(&self) -> [usize; 2]
Get the parents of the vertex.
sourcepub fn new_binary(
partial_x: f64,
parent_x: usize,
partial_y: f64,
parent_y: usize
) -> Self
pub fn new_binary( partial_x: f64, parent_x: usize, partial_y: f64, parent_y: usize ) -> Self
Instantiate a new vertex from a binary operation.
sourcepub fn new_unary(partial_x: f64, parent_x: usize) -> Self
pub fn new_unary(partial_x: f64, parent_x: usize) -> Self
Instantiate a new vertex from a unary operation.
sourcepub fn new_nullary() -> Self
pub fn new_nullary() -> Self
Instantiate a new vertex from a nullary operation.