Struct RustQuant::ml::regression::logistic::LogisticRegressionOutput
source · pub struct LogisticRegressionOutput<T> {
pub coefficients: DVector<T>,
pub iterations: usize,
}Expand description
Struct to hold the output data for a logistic regression.
Fields
coefficients: DVector<T>The coefficients of the logistic regression, often denoted as b0, b1, b2, …, bn. The first coefficient is the intercept (aka. b0 or alpha).
iterations: usizeNumber of iterations required to converge.
Implementations
sourceimpl LogisticRegressionOutput<f64>
impl LogisticRegressionOutput<f64>
sourcepub fn predict(&self, input: &DMatrix<f64>) -> DVector<f64>
pub fn predict(&self, input: &DMatrix<f64>) -> DVector<f64>
Predicts the output for the given input data.
sourcepub fn predict_proba(&self, input: &DMatrix<f64>) -> DVector<f64>
pub fn predict_proba(&self, input: &DMatrix<f64>) -> DVector<f64>
Compute the probabilities Pr(output_i=1|input_i,coefficients) for the given input data.