Module options

Module options 

Option pricers and sensitivity functions.

Modules

asian
Asian option pricers.
barrier
Barrier option pricers.
binary
Binary option pricers.
black_scholes_merton
Generalised Black-Scholes-Merton option pricer. The generalised Black-Scholes-Merton European Option pricing model.
finite_difference_pricer
Finite Difference Pricer
implied_volatility
Implied volatility functions. Let’s Be Rational rust implementation based on py_lets_be_rational and paper Let’s Be Rational by Peter Jaeckel with some modifications. If price is below intrinsic value, it returns -INF. If price is above intrinsic value, it returns INF.
log
Log contracts and options.
lookback
Lookback option pricers.
option_contract
Base option traits.
option_flags
Option flags.
option_models
Option models.
power
Power options and contracts.
supershare
Supershare options.
vanilla
Vanilla option.

Structs

Asay82
Asay (1982) option pricing parameters.
AsianOption
Asian option.
AsianOptionBuilder
Builder for AsianOption.
Bachelier
Bachelier (1900) option pricing parameters.
BarrierOption
Barrier option.
BinaryOption
Binary option.
Black76
Black (1976) option pricing parameters.
BlackScholes73
Black-Scholes (1973) option pricing parameters.
BlackScholesMerton
Generalised Black-Scholes-Merton European Option pricing model.
BlackScholesMertonBuilder
Builder for BlackScholesMerton.
CappedPowerOption
Capped Power Option.
EuropeanVanillaOption
European vanilla option.
EuropeanVanillaOptionBuilder
Builder for EuropeanVanillaOption.
GarmanKohlhagen83
Garman-Kohlhagen (1983) option pricing parameters.
Heston93
Heston (1993) option pricing parameters.
LogMoneynessContract
Log Moneyness Contract.
LogOption
Log Option.
LogUnderlyingContract
Log Underlying Contract.
LookbackOption
Lookback option.
Merton73
Meron (1973) option pricing parameters.
OptionContract
Option contract data.
OptionContractBuilder
Builder for OptionContract.
PowerContract
Power Contract.
PowerOption
Power Option. Not to be confused with the PoweredOption.
PoweredOption
Powered Option. Not to be confused with the PowerOption.
SupershareOption
Supershare option.

Enums

AsianOptionBuilderError
Error type for AsianOptionBuilder
AveragingMethod
Method of averaging (arithmetic or geometric, and continuous or discrete).
BarrierType
Barrier type flag.
BinaryType
Binary type enum.
BlackScholesMertonBuilderError
Error type for BlackScholesMertonBuilder
EuropeanVanillaOptionBuilderError
Error type for EuropeanVanillaOptionBuilder
ExerciseFlag
American/European option type enum.
OptionContractBuilderError
Error type for OptionContractBuilder
SettlementFlag
Instrument settlement flag.
StrikeFlag
Option strike type enum.
TypeFlag
Option type enum.

Traits

GeneralisedBlackScholesMerton
Generalised Black-Scholes-Merton option pricing model and it’s Greeks.

Functions

implied_volatility
Implied volatility function to calculate the implied volatility of an option given its market price. The method is based on lets be rational paper Let’s Be Rational by Peter Jaeckel with some modifications. If price is below intrinsic value, it returns -INF, if price is above intrinsic value, it returns INF.
iv
A convenience function to calculate the implied volatility. It is a wrapper around implied_volatility function.