pub enum ExerciseFlag {
European {
expiry: Date,
},
American {
start: Date,
end: Date,
},
Bermudan {
exercise_dates: Vec<Date>,
},
}Expand description
American/European option type enum.
Variants
European
European option (can only be exercised at expiry). Most index options are European.
American
American option (can be exercised at any time before expiry). Most stock options are American.
Bermudan
Bermudan option (can be exercised at specific dates before expiry). Bermudan options are a hybrid of American and European options, hence the name. These are relatively rare and typically used in OTC markets.
Implementations