pub struct Schedule {
pub dates: Vec<Date>,
pub day_count_factors: Vec<f64>,
pub day_counting_convention: DayCountConvention,
pub date_rolling_convention: DateRollingConvention,
}Expand description
Schedule struct.
Many financial instruments have a schedule of dates associated with them. For example, interest rate caps/floors have a schedule of payment dates, which are the expiration dates of the caplets/floorlets, or a coupon bond has a schedule of coupon payment dates.
The Schedule struct is used to represent these schedules, and pricing methods should be implemented using date/time functionality.
Fields
dates: Vec<Date>The dates of the schedule.
day_count_factors: Vec<f64>The day count factors of the schedule.
day_counting_convention: DayCountConventionThe convention of the schedule.
date_rolling_convention: DateRollingConventionThe business day convention of the schedule.