pub trait Scheduler {
// Required method
fn generate_schedule_from_dates(
&self,
dates: &[Date],
date_rolling_convention: DateRollingConvention,
day_counting_convention: DayCountConvention,
) -> Schedule;
}Expand description
The Scheduler trait.
This trait is used to generate schedules for a Calendar.
Required Methods
Sourcefn generate_schedule_from_dates(
&self,
dates: &[Date],
date_rolling_convention: DateRollingConvention,
day_counting_convention: DayCountConvention,
) -> Schedule
fn generate_schedule_from_dates( &self, dates: &[Date], date_rolling_convention: DateRollingConvention, day_counting_convention: DayCountConvention, ) -> Schedule
Generate a schedule from a slice of Dates.
For example, a list of coupon payment dates.
Note: The effective date is not included in the dates input, and assumed to be today.
Arguments
dates- A slice ofDates (such as coupon payment dates).date_rolling_convention- The date rolling convention.day_counting_convention- The day counting convention.