Module stochastics

Module stochastics 

The stochastics module.

Modules

arithmetic_brownian_motion
Arithmetic Brownian Motion.
black_derman_toy
Black-Derman-Toy short rate model.
brownian_motion
Standard Brownian Motion.
constant_elasticity_of_variance
Constant Elasticity of Variance process.
cox_ingersoll_ross
Cox-Ingersoll-Ross process.
curve_model
Curve model trait. Curves models module.
extended_vasicek
Extended Vasicek process.
fractional_brownian_motion
Fractional Brownian Motion.
fractional_cox_ingersoll_ross
Fractional Cox-Ingersoll-Ross process.
fractional_ornstein_uhlenbeck
Fractional Ornstein-Uhlenbeck process.
geometric_brownian_bridge
Geometric brownian bridge process.
geometric_brownian_motion
Geometric Brownian Motion.
heston
Heston model process.
ho_lee
Ho-Lee process.
hull_white
Hull-White model process.
merton_jump_diffusion
Merton jump diffusion process.
model_parameter
Model parameter struct.
nelson_siegel_svensson
Nelson-Siegel-Svensson model process.
ornstein_uhlenbeck
Ornstein-Uhlenbeck process.
process
Defines Trajectories and StochasticProcess. Trajectories is the return type of all the stochastic processes. StochasticProcess is the base trait for all the stochastic processes.
sabr
SABR model process.

Structs

ArithmeticBrownianMotion
Struct containing the Arithmetic Brownian Motion parameters.
BlackDermanToy
Struct containing the Black-Derman-Toy process parameters.
BrownianMotion
Struct containing the Geometric Brownian Motion parameters.
ConstantElasticityOfVariance
Struct containing the CEV process parameters.
CoxIngersollRoss
Struct containing the Ornstein-Uhlenbeck process parameters.
ExtendedVasicek
Struct containing the extended Vasicek process parameters.
FractionalBrownianMotion
Struct containing the Fractional Brownian Motion parameters.
FractionalCoxIngersollRoss
Struct containing the Ornstein-Uhlenbeck process parameters.
FractionalOrnsteinUhlenbeck
Struct containing the Ornstein-Uhlenbeck process parameters.
GeometricBrownianBridge
Struct containing the Geometric Brownian Bridge parameters. The Geometric Brownian Bridge is a stochastic process that models a path-dependent option. It is a modification of the Geometric Brownian Motion where the end value is known.
GeometricBrownianMotion
Struct containing the Geometric Brownian Motion parameters.
Heston
Struct containing the Heston model parameters.
HoLee
Struct containing the Ho-Lee process parameters.
HullWhite
Struct containing the Hull-White process parameters.
MertonJumpDiffusion
Struct containing the Merton Jump Diffusion parameters. The Merton Jump Diffusion is a stochastic process that models a path-dependent option. It is a modification of the Geometric Brownian Motion where the end value is known.
ModelParameter
A struct that wraps constants and functions into a single type in order to allow for all processes to have time-dependent parameters.
NelsonSiegelSvensson
Nelson-Siegel-Svensson (1994) model parameters.
OrnsteinUhlenbeck
Struct containing the Ornstein-Uhlenbeck process parameters.
SABR
Struct containing the Heston model parameters.
StochasticProcessConfig
Configuration parameters for simulating a stochastic process.
Trajectories
Struct to contain the time points and path values of the process.

Enums

FractionalProcessGeneratorMethod
Method used to generate the Fractional Brownian Motion.

Traits

CurveModel
A trait for curve models.
StochasticProcess
Trait to implement stochastic processes.
StochasticVolatilityProcess
Trait to implement stochastic volatility processes.