FractionalCoxIngersollRoss

Struct FractionalCoxIngersollRoss 

pub struct FractionalCoxIngersollRoss {
    pub mu: ModelParameter,
    pub sigma: ModelParameter,
    pub theta: ModelParameter,
    pub hurst: f64,
    pub method: FractionalProcessGeneratorMethod,
}
Struct containing the Ornstein-Uhlenbeck process parameters.

Fields

mu: ModelParameter

The long-run mean ($\mu$).

sigma: ModelParameter

The diffusion, or instantaneous volatility ($\sigma$).

theta: ModelParameter

Mean reversion parameter ($\theta$). Defines the speed at which the process reverts to the long-run mean.

hurst: f64

Hurst parameter of the process. The Hurst parameter is a measure of the long-term memory of the process.

method: FractionalProcessGeneratorMethod

Method to generate Fractional Gaussian Noise.

Implementations

Source

impl FractionalCoxIngersollRoss

pub fn new( mu: impl Into<ModelParameter>, sigma: impl Into<ModelParameter>, theta: impl Into<ModelParameter>, hurst: f64, method: FractionalProcessGeneratorMethod, ) -> FractionalCoxIngersollRoss

Create a new Ornstein-Uhlenbeck process.