pub struct FractionalOrnsteinUhlenbeck {
pub mu: ModelParameter,
pub sigma: ModelParameter,
pub theta: ModelParameter,
pub hurst: f64,
pub method: FractionalProcessGeneratorMethod,
}Expand description
Struct containing the Ornstein-Uhlenbeck process parameters.
Fields
mu: ModelParameterThe long-run mean ($\mu$).
sigma: ModelParameterThe diffusion, or instantaneous volatility ($\sigma$).
theta: ModelParameterMean reversion parameter ($\theta$). Defines the speed at which the process reverts to the long-run mean.
hurst: f64Hurst parameter of the process. The Hurst parameter is a measure of the long-term memory of the process.
method: FractionalProcessGeneratorMethodMethod to generate Fractional Gaussian Noise.
Implementations
Sourceimpl FractionalOrnsteinUhlenbeck
impl FractionalOrnsteinUhlenbeck
Sourcepub fn new(
mu: impl Into<ModelParameter>,
sigma: impl Into<ModelParameter>,
theta: impl Into<ModelParameter>,
hurst: f64,
method: FractionalProcessGeneratorMethod,
) -> FractionalOrnsteinUhlenbeck
pub fn new( mu: impl Into<ModelParameter>, sigma: impl Into<ModelParameter>, theta: impl Into<ModelParameter>, hurst: f64, method: FractionalProcessGeneratorMethod, ) -> FractionalOrnsteinUhlenbeck
Create a new Ornstein-Uhlenbeck process.