pub struct ModelParameter(pub Box<dyn Fn(f64) -> f64 + Sync + Send>);Expand description
A struct that wraps constants and functions into a single type in order to allow for all processes to have time-dependent parameters.
Tuple Fields
0: Box<dyn Fn(f64) -> f64 + Sync + Send>Trait Implementations
Sourceimpl Debug for ModelParameter
impl Debug for ModelParameter
Sourceimpl<F> From<F> for ModelParameter
impl<F> From<F> for ModelParameter
Sourcefn from(func: F) -> ModelParameter
fn from(func: F) -> ModelParameter
Converts to this type from the input type.
Sourceimpl From<f64> for ModelParameter
impl From<f64> for ModelParameter
Sourcefn from(x: f64) -> ModelParameter
fn from(x: f64) -> ModelParameter
Converts to this type from the input type.