Module RustQuant::autodiff

source ·
Parent module containing: automatic differentation modules.

Re-exports

  • pub use crate::autodiff::gradient::*;
  • pub use crate::autodiff::overload::*;
  • pub use crate::autodiff::tape::*;
  • pub use crate::autodiff::variable::*;

Modules

  • Submodule of autodiff: implements the gradient computation. This module contains the Gradient trait. Each implementation of wrt returns the chosen partial derivatives.
  • Submodule of autodiff: implements operator/function overloading. This module contains the overloaded operators and primitive functions. Operations such as + and * are redefined, along with primitive functions such as sin, exp, and log.
  • Submodule of autodiff: implements the Tape (Wengert List). This module contains the implementation of the Tape. The tape is also known as a Wengert List.
  • Submodule of autodiff: implements Variables for autodiff. This module contains the implementation of the Variable structure.