Parent module containing: automatic differentation modules.
Re-exports
pub use crate::autodiff::gradient::*;pub use crate::autodiff::overload::*;pub use crate::autodiff::tape::*;pub use crate::autodiff::variable::*;
Modules
- Submodule of
autodiff: implements the gradient computation. This module contains theGradienttrait. Each implementation ofwrtreturns the chosen partial derivatives. - Submodule of
autodiff: implements operator/function overloading. This module contains the overloaded operators and primitive functions. Operations such as+and*are redefined, along with primitive functions such assin,exp, andlog. - Submodule of
autodiff: implements the Tape (Wengert List). This module contains the implementation of theTape. The tape is also known as a Wengert List. - Submodule of
autodiff: implementsVariables forautodiff. This module contains the implementation of theVariablestructure.