The Graph (aka. tape or Wengert List).
This module contains the implementation of the computation Graph.
The graph is also known as a Wengert List.
The graph is an abstract data structure that contains Vertexs. These
contain the adjoints and indices to the parent vertices.
Structs
- Struct to contain the graph (Wengert list), as a vector of
Vertexs.