Submodule of autodiff: implements Variables for autodiff.
This module contains the implementation of the Variable structure.
Variables are used to create input variables and contain:
- a pointer to their tape
- an index to their node
- an associated value.
Structs
- Struct to contain the initial variables.