Option pricers and sensitivity functions.
Modules
- asian
- Asian option pricers.
- barrier
- Barrier option pricers.
- binary
- Binary option pricers.
- black_
scholes_ merton - Generalised Black-Scholes-Merton option pricer. The generalised Black-Scholes-Merton European Option pricing model.
- finite_
difference_ pricer - Finite Difference Pricer
- implied_
volatility - Implied volatility functions. Let’s Be Rational rust implementation based on py_lets_be_rational and paper Let’s Be Rational by Peter Jaeckel with some modifications. If price is below intrinsic value, it returns -INF. If price is above intrinsic value, it returns INF.
- log
- Log contracts and options.
- lookback
- Lookback option pricers.
- option_
contract - Base option traits.
- option_
flags - Option flags.
- option_
models - Option models.
- power
- Power options and contracts.
- supershare
- Supershare options.
- vanilla
- Vanilla option.
Structs
- Asay82
- Asay (1982) option pricing parameters.
- Asian
Option - Asian option.
- Asian
Option Builder - Builder for
AsianOption. - Bachelier
- Bachelier (1900) option pricing parameters.
- Barrier
Option - Barrier option.
- Binary
Option - Binary option.
- Black76
- Black (1976) option pricing parameters.
- Black
Scholes73 - Black-Scholes (1973) option pricing parameters.
- Black
Scholes Merton - Generalised Black-Scholes-Merton European Option pricing model.
- Black
Scholes Merton Builder - Builder for
BlackScholesMerton. - Capped
Power Option - Capped Power Option.
- European
Vanilla Option - European vanilla option.
- European
Vanilla Option Builder - Builder for
EuropeanVanillaOption. - Garman
Kohlhagen83 - Garman-Kohlhagen (1983) option pricing parameters.
- Heston93
- Heston (1993) option pricing parameters.
- LogMoneyness
Contract - Log Moneyness Contract.
- LogOption
- Log Option.
- LogUnderlying
Contract - Log Underlying Contract.
- Lookback
Option - Lookback option.
- Merton73
- Meron (1973) option pricing parameters.
- Option
Contract - Option contract data.
- Option
Contract Builder - Builder for
OptionContract. - Power
Contract - Power Contract.
- Power
Option - Power Option. Not to be confused with the PoweredOption.
- Powered
Option - Powered Option. Not to be confused with the PowerOption.
- Supershare
Option - Supershare option.
Enums
- Asian
Option Builder Error - Error type for AsianOptionBuilder
- Averaging
Method - Method of averaging (arithmetic or geometric, and continuous or discrete).
- Barrier
Type - Barrier type flag.
- Binary
Type - Binary type enum.
- Black
Scholes Merton Builder Error - Error type for BlackScholesMertonBuilder
- European
Vanilla Option Builder Error - Error type for EuropeanVanillaOptionBuilder
- Exercise
Flag - American/European option type enum.
- Option
Contract Builder Error - Error type for OptionContractBuilder
- Settlement
Flag - Instrument settlement flag.
- Strike
Flag - Option strike type enum.
- Type
Flag - Option type enum.
Traits
- Generalised
Black Scholes Merton - Generalised Black-Scholes-Merton option pricing model and it’s Greeks.
Functions
- implied_
volatility - Implied volatility function to calculate the implied volatility of an option given its market price. The method is based on lets be rational paper Let’s Be Rational by Peter Jaeckel with some modifications. If price is below intrinsic value, it returns -INF, if price is above intrinsic value, it returns INF.
- iv
- A convenience function to calculate the implied volatility.
It is a wrapper around
implied_volatilityfunction.