pub struct GeometricBrownianBridge {
pub mu: ModelParameter,
pub sigma: ModelParameter,
pub end_value: f64,
pub end_time: f64,
}Expand description
Struct containing the Geometric Brownian Bridge parameters. The Geometric Brownian Bridge is a stochastic process that models a path-dependent option. It is a modification of the Geometric Brownian Motion where the end value is known.
Fields
mu: ModelParameterThe drift ($\mu$) in percentage.
sigma: ModelParameterThe volatility ($\sigma$) in percentage.
end_value: f64The known end value of the process.
end_time: f64The known end time of the process.
Implementations
Sourceimpl GeometricBrownianBridge
impl GeometricBrownianBridge
Sourcepub fn new(
mu: impl Into<ModelParameter>,
sigma: impl Into<ModelParameter>,
end_value: f64,
end_time: f64,
) -> GeometricBrownianBridge
pub fn new( mu: impl Into<ModelParameter>, sigma: impl Into<ModelParameter>, end_value: f64, end_time: f64, ) -> GeometricBrownianBridge
Create a new Geometric Brownian Bridge process.
Arguments
mu- The drift ($\mu$) in percentage.sigma- The volatility ($\sigma$) in percentage.end_value- The known end value of the process.end_time- The known end time of the process.