The stochastics module.
Modules
- arithmetic_
brownian_ motion - Arithmetic Brownian Motion.
- black_
derman_ toy - Black-Derman-Toy short rate model.
- brownian_
motion - Standard Brownian Motion.
- constant_
elasticity_ of_ variance - Constant Elasticity of Variance process.
- cox_
ingersoll_ ross - Cox-Ingersoll-Ross process.
- curve_
model - Curve model trait. Curves models module.
- extended_
vasicek - Extended Vasicek process.
- fractional_
brownian_ motion - Fractional Brownian Motion.
- fractional_
cox_ ingersoll_ ross - Fractional Cox-Ingersoll-Ross process.
- fractional_
ornstein_ uhlenbeck - Fractional Ornstein-Uhlenbeck process.
- geometric_
brownian_ bridge - Geometric brownian bridge process.
- geometric_
brownian_ motion - Geometric Brownian Motion.
- heston
- Heston model process.
- ho_lee
- Ho-Lee process.
- hull_
white - Hull-White model process.
- merton_
jump_ diffusion - Merton jump diffusion process.
- model_
parameter - Model parameter struct.
- nelson_
siegel_ svensson - Nelson-Siegel-Svensson model process.
- ornstein_
uhlenbeck - Ornstein-Uhlenbeck process.
- process
- Defines
TrajectoriesandStochasticProcess.Trajectoriesis the return type of all the stochastic processes.StochasticProcessis the base trait for all the stochastic processes. - sabr
- SABR model process.
Structs
- Arithmetic
Brownian Motion - Struct containing the Arithmetic Brownian Motion parameters.
- Black
Derman Toy - Struct containing the Black-Derman-Toy process parameters.
- Brownian
Motion - Struct containing the Geometric Brownian Motion parameters.
- Constant
Elasticity OfVariance - Struct containing the CEV process parameters.
- CoxIngersoll
Ross - Struct containing the Ornstein-Uhlenbeck process parameters.
- Extended
Vasicek - Struct containing the extended Vasicek process parameters.
- Fractional
Brownian Motion - Struct containing the Fractional Brownian Motion parameters.
- Fractional
CoxIngersoll Ross - Struct containing the Ornstein-Uhlenbeck process parameters.
- Fractional
Ornstein Uhlenbeck - Struct containing the Ornstein-Uhlenbeck process parameters.
- Geometric
Brownian Bridge - Struct containing the Geometric Brownian Bridge parameters. The Geometric Brownian Bridge is a stochastic process that models a path-dependent option. It is a modification of the Geometric Brownian Motion where the end value is known.
- Geometric
Brownian Motion - Struct containing the Geometric Brownian Motion parameters.
- Heston
- Struct containing the Heston model parameters.
- HoLee
- Struct containing the Ho-Lee process parameters.
- Hull
White - Struct containing the Hull-White process parameters.
- Merton
Jump Diffusion - Struct containing the Merton Jump Diffusion parameters. The Merton Jump Diffusion is a stochastic process that models a path-dependent option. It is a modification of the Geometric Brownian Motion where the end value is known.
- Model
Parameter - A struct that wraps constants and functions into a single type in order to allow for all processes to have time-dependent parameters.
- Nelson
Siegel Svensson - Nelson-Siegel-Svensson (1994) model parameters.
- Ornstein
Uhlenbeck - Struct containing the Ornstein-Uhlenbeck process parameters.
- SABR
- Struct containing the Heston model parameters.
- Stochastic
Process Config - Configuration parameters for simulating a stochastic process.
- Trajectories
- Struct to contain the time points and path values of the process.
Enums
- Fractional
Process Generator Method - Method used to generate the Fractional Brownian Motion.
Traits
- Curve
Model - A trait for curve models.
- Stochastic
Process - Trait to implement stochastic processes.
- Stochastic
Volatility Process - Trait to implement stochastic volatility processes.