pub fn today() -> DateExpand description
Retrieve today’s date (local time).
Warning:
Depending on where the code is physically run, the date may be different. For example, two machines calling this function at precisely the same time in Australia and the United States will get different dates.